/* libgputils header
   Copyright (C) 2001, 2002, 2003, 2004
   Craig Franklin

This file is part of gputils.

gputils is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

gputils is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with gputils; see the file COPYING.  If not, write to
the Free Software Foundation, 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA.  */

#ifndef __LIBGPUTILS_H__
#define __LIBGPUTILS_H__

/* library files */
#include <gptypes.h>
#include <gpsystem.h>
#include <gpmessage.h>

/* common files */
#include <gpmemory.h>
#include <gpopcode.h>
#include <gpprocessor.h>
#include <gpsymbol.h>
#include <gpdis.h>
#include <gpwritehex.h>
#include <gpreadhex.h>

/* COFF files */
#include <gpcoff.h>
#include <gparchive.h>
#include <gpcoffgen.h>
#include <gpcofflink.h>
#include <gpreadobj.h>
#include <gpwriteobj.h>

/* COD files */
#include <gpcod.h>

#endif
